==> p5-GRNOC-TL1-1.2.2.tbz: lib/perl5/site_perl/5.14.2/GRNOC/TL1/Device/Nortel/OME6500.pm <==
#--------------------------------------------------------------------
#----- GRNOC TL1 Nortel OME6500 Device Module
#-----
#----- Copyright(C) 2008 The Trustees of Indiana University
#--------------------------------------------------------------------
#----- $HeadURL: $
#----- $Id: $
#-----
#----- This module handles the functionality for the Nortel OME6500 TL1 device.  It
#----- inherts from the standard GRNOC::TL1::Device module.
#--------------------------------------------------------------------

package GRNOC::TL1::Device::Nortel::OME6500;
use base "GRNOC::TL1::Device";

use Data::Dumper;
use Date::Calc qw(Monday_of_Week);
use strict;

sub new {

  my $caller = shift;
  my $class = ref($caller) || $caller;
  
  my (%args) = @_;

  # set default port used for OME6500 if one was not given
  $args{'port'} = 23 if ($args{'port'} eq '');

  # set default prompt used for OME6500 if one was not given
  $args{'prompt'} = '<' if ($args{'prompt'} eq '');

  # call the GRNOC::TL1::Device structure
  my $self = $class->SUPER::new(%args);

  bless($self, $class);
  
  return $self;
}

sub get_alarms {

  my $self = shift;
  
  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};
  
  my $cmd = "RTRV-ALM-ALL:$tid" . "::$ctag;";

  my @output_messages = $self->parse($self->cmd($cmd));
  my @responses = $self->get_responses(@output_messages);
  my @alarms;

  foreach my $response (@responses) {

    my $alarm;

    if ($response =~ /"([^,]*),([^:]*):([^,]*),([^,]*),([^,]*),([^,]*),([^,]*),([^,]*),([^:]*):\\\"([^\\]*)\\\",[^:]*:([^-]*)-([^-]*)-([^,]*),:YEAR=([^,]*),MODE=([^\"]*)\"/) {
      
      $alarm->{'aid'} = $1;
      $alarm->{'aid_type'} = $2;
      $alarm->{'not_code'} = $3;
      $alarm->{'cond_type'} = $4;
      $alarm->{'serv_affect'} = $5;
      $alarm->{'month_day'} = $6;
      $alarm->{'time'} = $7;
      $alarm->{'location'} = $8;
      $alarm->{'direction'} = $9;
      $alarm->{'description'} = $10;
      $alarm->{'id'} = $11;
      $alarm->{'prob_cause'} = $12;
      $alarm->{'doc_index'} = $13;
      $alarm->{'year'} = $14;
      $alarm->{'mode'} = $15;
      
      my @two = split(/-/, $alarm->{'month_day'});
      $alarm->{'month'} = $two[0];
      $alarm->{'day'} = $two[1];
      
      $alarm->{'time'} =~ s/-/:/g;
      
      push(@alarms, $alarm);
    }

    else {

      print STDERR "get_alarms: Error parsing response: $response\n";
    }
  }
  
  return @alarms;
}

sub get_inventory {

  my $self = shift;
  
  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};
  
  my $cmd = "RTRV-INVENTORY:$tid" . "::$ctag;";

  my @output_messages = $self->parse($self->cmd($cmd));
  my @responses = $self->get_responses(@output_messages);
  my @inventory;

  foreach my $response (@responses) {

    my $device;

    if ($response =~ /^"([^:]+)::.*"$/) {

      $device->{'aid'} = $1;

      # skip over it if it doesn't have a CTYPE (empty & filler slots)
      next if ($response !~ /CTYPE=/);

      ($device->{'type'}) = $response =~ /CTYPE=\\"([^\\"]+)\\"/;
      ($device->{'snmp_index'}) = $response =~ /SNMPINDEX=([^,|^"]+)/;
      ($device->{'pec'}) = $response =~ /PEC=([^,|^"]+)/;
      ($device->{'version'}) = $response =~ /REL=([^,|^"]+)/;
      ($device->{'clei'}) = $response =~ /CLEI=([^,|^"]+)/;
      ($device->{'serial'}) = $response =~ /SER=([^,|^"]+)/;
      ($device->{'date'}) = $response =~ /MDAT=([^,|^"]+)/;

      $device->{'version'} =~ s/^\s//;
      $device->{'version'} =~ s/\s$//;

      # reformat date to be month-year if needed
      if ($device->{'date'} ne "") {
	
	my ($year, $week) = split(/-/, $device->{'date'});
	my ($year, $month, $day) = Monday_of_Week($week, $year);
	$device->{'date'} = $month . "-" . $year;
      }

      push(@inventory, $device);
    }
    
    else {
      
      print STDERR "get_inventory: Error parsing response: $response\n";
    }
  }

  return @inventory;
}

sub get_cross_connects {

  my $self = shift;
  
  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};
  
  my $cmd = "RTRV-CRS-ALL:$tid" . "::$ctag;";

  my @output_messages = $self->parse($self->cmd($cmd));
  my @responses = $self->get_responses(@output_messages);
  my @cross_connects;

  foreach my $response (@responses) {

    my $cross_connect;

    if ($response =~ /^"([^,]+),([^:]+):([^:]*):.*:([^:]+):"$/) {

      $cross_connect->{'from_aid'} = $1;
      $cross_connect->{'to_aid'} = $2;
      $cross_connect->{'type'} = $3;
      $cross_connect->{'rate'} = $4;

      ($cross_connect->{'description'}) = $response =~ /CKTID=([^,]*),/;
      
      push(@cross_connects, $cross_connect);
    }
    
    else {
      
      print STDERR "get_cross_connects: Error parsing response: $response\n";
    }
  }

  return @cross_connects;
}

1;

==> p5-GRNOC-TL1-1.3.10.tbz: lib/perl5/site_perl/5.14/GRNOC/TL1/Device/Nortel/OME6500.pm <==
#--------------------------------------------------------------------
#----- GRNOC TL1 Nortel OME6500 Device Module
#-----
#----- Copyright(C) 2008 The Trustees of Indiana University
#--------------------------------------------------------------------
#----- $HeadURL: $
#----- $Id: $
#-----
#----- This module handles the functionality for the Nortel OME6500 TL1 device.  It
#----- inherts from the standard GRNOC::TL1::Device module.
#--------------------------------------------------------------------

package GRNOC::TL1::Device::Nortel::OME6500;
use base "GRNOC::TL1::Device";

use Data::Dumper;
use Date::Calc qw(Monday_of_Week);
use strict;

sub new {

  my $caller = shift;
  my $class = ref($caller) || $caller;

  my (%args) = @_;

  # set default port used for OME6500 if one was not given
  $args{'port'} = 23 if ($args{'port'} eq '');

  # set default prompt used for OME6500 if one was not given
  $args{'prompt'} = '<' if ($args{'prompt'} eq '');

  # call the GRNOC::TL1::Device structure
  my $self = $class->SUPER::new(%args);

  bless($self, $class);

  return $self;
}

sub get_alarms {

  my $self = shift;

  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};

  my $cmd = "RTRV-ALM-ALL:$tid" . "::$ctag;";

  my $cmd_output = $self->cmd($cmd);
  return undef if (!defined $cmd_output);

  my @output_messages = $self->parse($cmd_output);
  my @responses = $self->get_responses(@output_messages);
  my @alarms;

  foreach my $response (@responses) {

    my $alarm;

    if ($response =~ /"([^,]*),([^:]*):([^,]*),([^,]*),([^,]*),([^,]*),([^,]*),([^,]*),([^:]*):\\\"([^\\]*)\\\",[^:]*:([^-]*)-([^-]*)-([^,]*),:YEAR=([^,]*),MODE=([^\"]*)\"/) {

      $alarm->{'aid'} = $1;
      $alarm->{'aid_type'} = $2;
      $alarm->{'not_code'} = $3;
      $alarm->{'cond_type'} = $4;
      $alarm->{'serv_affect'} = $5;
      $alarm->{'month_day'} = $6;
      $alarm->{'time'} = $7;
      $alarm->{'location'} = $8;
      $alarm->{'direction'} = $9;
      $alarm->{'description'} = $10;
      $alarm->{'id'} = $11;
      $alarm->{'prob_cause'} = $12;
      $alarm->{'doc_index'} = $13;
      $alarm->{'year'} = $14;
      $alarm->{'mode'} = $15;

      my @two = split(/-/, $alarm->{'month_day'});
      $alarm->{'month'} = $two[0];
      $alarm->{'day'} = $two[1];

      $alarm->{'time'} =~ s/-/:/g;

      push(@alarms, $alarm);
    }

    else {

      print STDERR "get_alarms: Error parsing response: $response\n";
    }
  }

  return @alarms;
}

sub get_inventory {

  my $self = shift;

  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};

  my $cmd = "RTRV-INVENTORY:$tid" . "::$ctag;";

  my $cmd_output = $self->cmd($cmd);
  return undef if (!defined $cmd_output);

  my @output_messages = $self->parse($cmd_output);
  my @responses = $self->get_responses(@output_messages);
  my @inventory;

  foreach my $response (@responses) {

    my $device;

    if ($response =~ /^"([^:]+)::.*"$/) {

      $device->{'aid'} = $1;

      # skip over it if it doesn't have a CTYPE (empty & filler slots)
      next if ($response !~ /CTYPE=/);

      ($device->{'type'}) = $response =~ /CTYPE=\\"([^\\"]+)\\"/;
      ($device->{'snmp_index'}) = $response =~ /SNMPINDEX=([^,|^"]+)/;
      ($device->{'pec'}) = $response =~ /PEC=([^,|^"]+)/;
      ($device->{'version'}) = $response =~ /REL=([^,|^"]+)/;
      ($device->{'clei'}) = $response =~ /CLEI=([^,|^"]+)/;
      ($device->{'serial'}) = $response =~ /SER=([^,|^"]+)/;
      ($device->{'date'}) = $response =~ /MDAT=([^,|^"]+)/;

      $device->{'version'} =~ s/^\s//;
      $device->{'version'} =~ s/\s$//;

      # reformat date to be month-year if needed
      if ($device->{'date'} ne "") {

        my $year;
        my $week;
        my $month;
        my $day;

        ( $year, $week ) = split( /-/, $device->{'date'} );
        ( $year, $month, $day ) = Monday_of_Week( $week, $year );

        $device->{'date'} = $month . "-" . $year;
      }

      push(@inventory, $device);
    }

    else {

      print STDERR "get_inventory: Error parsing response: $response\n";
    }
  }

  return @inventory;
}

sub get_cross_connects {

  my $self = shift;

  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};

  my $cmd = "RTRV-CRS-ALL:$tid" . "::$ctag;";

  my $cmd_output = $self->cmd($cmd);
  return undef if (!defined $cmd_output);

  my @output_messages = $self->parse($cmd_output);
  my @responses = $self->get_responses(@output_messages);
  my @cross_connects;

  foreach my $response (@responses) {

    my $cross_connect;

    if ($response =~ /^"([^,]+),([^:]+):([^:]*):.*:([^:]+):"$/) {

      $cross_connect->{'from_aid'} = $1;
      $cross_connect->{'to_aid'} = $2;
      $cross_connect->{'type'} = $3;
      $cross_connect->{'rate'} = $4;

      ($cross_connect->{'description'}) = $response =~ /CKTID=([^,]*),/;

      push(@cross_connects, $cross_connect);
    }

    else {

      print STDERR "get_cross_connects: Error parsing response: $response\n";
    }
  }

  return @cross_connects;
}

1;
